@@ -2,7 +2,7 @@ package PICA::Writer::PPXML;
 use strict;
 use warnings;
 
-our $VERSION = '1.03';
+our $VERSION = '1.01';
 
 use Scalar::Util qw(reftype);
 use XML::LibXML;
@@ -23,16 +23,6 @@ sub write_record {
     my ($self, $record) = @_;
     $record = $record->{record} if reftype $record eq 'HASH';
 
-    my $i = 0;
-    my $pica_sort = sub {
-        my $f = shift;
-        my $oc  = ($f->[1] eq '') ? '00' : $f->[1];
-        $oc = ($f->[0] eq '101@') ? ++$i . $oc : $i . $oc;
-        return [$oc.$f->[0], $f];
-    };
-
-    @$record = map $_->[1], sort { $a->[0] cmp $b->[0] } map { $pica_sort->($_) } @$record;
-    
     my $el_record = $self->{collection}->addNewChild("", "record");
     $el_record->setNamespace(NS, "ppxml");
     
